==> nextcloud-28.0.8.tgz: nextcloud/apps/comments/l10n/sk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentáre",
    "You commented" : "Komentovali ste",
    "{author} commented" : "{author} komentoval",
    "You commented on %1$s" : "Komentovali ste %1$s",
    "You commented on {file}" : "Komentovali ste {file}",
    "%1$s commented on %2$s" : "%1$s komentoval %2$s",
    "{author} commented on {file}" : "{author} komentoval {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentáre</strong> pre súbory",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Boli ste spomenutý v \"{file}\", v komentári užívateľom ktorý bol už vymazaný",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} vás spomenul v komentári k “{file}”",
    "Files app plugin to add comments to files" : "Zásuvný modul aplikácie súborov, ktorý umožňuje súborom pridávať komentáre",
    "Edit comment" : "Upraviť komentár",
    "Delete comment" : "Zmazať komentár",
    "Cancel edit" : "Zrušiť upravovanie",
    "New comment" : "Nový komentár",
    "Write a comment …" : "Napísať komentár ...",
    "Post comment" : "Odoslať komentár",
    "@ for mentions, : for emoji, / for smart picker" : "@ pre spomienky, : pre emotikony, / pre inteligentný výber",
    "Could not reload comments" : "Nepodarilo sa obnoviť komentáre",
    "No comments yet, start the conversation!" : "Žiadne komentáre, začnite konverzáciu!",
    "No more messages" : "Žiadne ďaĺšie správy",
    "Retry" : "Skúsiť znova",
    "Failed to mark comments as read" : "Nepodarilo sa označiť komentáre ako prečítané.",
    "Unable to load the comments list" : "Nie je možné načítať zoznam komentárov",
    "_1 new comment_::_{unread} new comments_" : ["1 nový komentár","{unread} nové komentáre","{unread} nových komentárov","{unread} nových komentárov"],
    "Comment" : "Komentár",
    "An error occurred while trying to edit the comment" : "Vyskytla sa chyba pri editovaní komentára",
    "Comment deleted" : "Komentár bol odstránený",
    "An error occurred while trying to delete the comment" : "Vyskytla sa chyba pri mazaní komentára",
    "An error occurred while trying to create the comment" : "Vyskytla sa chyba pri vytváraní komentára",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Boli ste spomenutý v \"{file}\", v komentári používateľom ktorý bol už vymazaný",
    "Write a message …" : "Píšte správu …",
    "\"@\" for mentions, \":\" for emoji, \"/\" for smart picker" : "\"@\" pre spomienky, \":\" pre emotikony, \"/\" pre inteligentný výber",
    "_%n unread comment_::_%n unread comments_" : ["%n neprečítaný komentár","%n neprečítaných komentárov","%n neprečítaných komentárov","%n neprečítaných komentárov"]
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-28.0.14.tgz: nextcloud/apps/comments/l10n/sk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentáre",
    "You commented" : "Komentovali ste",
    "{author} commented" : "{author} komentoval",
    "You commented on %1$s" : "Komentovali ste %1$s",
    "You commented on {file}" : "Komentovali ste {file}",
    "%1$s commented on %2$s" : "%1$s komentoval %2$s",
    "{author} commented on {file}" : "{author} komentoval {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentáre</strong> pre súbory",
    "Files" : "Súbory",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Boli ste spomenutý v \"{file}\", v komentári užívateľom ktorý bol už vymazaný",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} vás spomenul v komentári k “{file}”",
    "Files app plugin to add comments to files" : "Zásuvný modul aplikácie súborov, ktorý umožňuje súborom pridávať komentáre",
    "Edit comment" : "Upraviť komentár",
    "Delete comment" : "Zmazať komentár",
    "Cancel edit" : "Zrušiť upravovanie",
    "New comment" : "Nový komentár",
    "Write a comment …" : "Napísať komentár ...",
    "Post comment" : "Odoslať komentár",
    "@ for mentions, : for emoji, / for smart picker" : "@ pre spomienky, : pre emotikony, / pre inteligentný výber",
    "Could not reload comments" : "Nepodarilo sa obnoviť komentáre",
    "No comments yet, start the conversation!" : "Žiadne komentáre, začnite konverzáciu!",
    "No more messages" : "Žiadne ďaĺšie správy",
    "Retry" : "Skúsiť znova",
    "Failed to mark comments as read" : "Nepodarilo sa označiť komentáre ako prečítané.",
    "Unable to load the comments list" : "Nie je možné načítať zoznam komentárov",
    "_1 new comment_::_{unread} new comments_" : ["1 nový komentár","{unread} nové komentáre","{unread} nových komentárov","{unread} nových komentárov"],
    "Comment" : "Komentár",
    "An error occurred while trying to edit the comment" : "Vyskytla sa chyba pri editovaní komentára",
    "Comment deleted" : "Komentár bol odstránený",
    "An error occurred while trying to delete the comment" : "Vyskytla sa chyba pri mazaní komentára",
    "An error occurred while trying to create the comment" : "Vyskytla sa chyba pri vytváraní komentára",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Boli ste spomenutý v \"{file}\", v komentári používateľom ktorý bol už vymazaný"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
